from data_skill_hub.extract_consultants import (
    ExportConfig,
    Poste,
    Section,
    DossierCompetencePret,
    flat_export,
)


# part test


def test_flat_export():
    config = ExportConfig(
        nom_prenom="Bob pipo",
        dossiers=[
            Poste(
                poste="Data Scientist",
                sections=[
                    Section(titre="Compétences1", file="competence.md"),
                    Section(titre="Diplôme1", file="diplome.md"),
                ],
            ),
            Poste(
                poste="Data Engineer",
                sections=[
                    Section(titre="Expérience2", file="experience.md"),
                    Section(titre="Langue2", file="langue.md"),
                ],
            ),
        ],
    )
    liste_dcp = [
        DossierCompetencePret(
            name="Bob pipo",
            poste="Data Scientist",
            sections=[
                Section(titre="Compétences1", file="competence.md"),
                Section(titre="Diplôme1", file="diplome.md"),
            ],
        ),
        DossierCompetencePret(
            name="Bob pipo",
            poste="Data Engineer",
            sections=[
                Section(titre="Expérience2", file="experience.md"),
                Section(titre="Langue2", file="langue.md"),
            ],
        ),
    ]
    assert flat_export(config) == liste_dcp



import click
from .extract_consultants import get_cvs
from .export import write_exports
from .init_src import creer_dossier, copy_file

BASE_PATH = "sources_exemple"
DESTINATION_PATH = "src"
OUTPUT_PATH = "src/outputs"


@click.group()
def main():
    pass


@main.command()
def init():
    list_dossier = ["assets", "templates", "config", "consultants"]
    for dossier in list_dossier:
        creer_dossier(f"{DESTINATION_PATH}/{dossier}/")
    print("dossier créé")
    copy_file(f"{BASE_PATH}/assets", f"{DESTINATION_PATH}/assets", "logo_pied.png")  # noqa:
    copy_file(f"{BASE_PATH}/assets", f"{DESTINATION_PATH}/assets", "Datalyo_logo_rvb.png") # noqa:
    copy_file(f"{BASE_PATH}/assets", f"{DESTINATION_PATH}/assets", "test.css")
    copy_file(f"{BASE_PATH}/templates", f"{DESTINATION_PATH}/templates", "temp_cv.html")  # noqa:
    copy_file(f"{BASE_PATH}/config", f"{DESTINATION_PATH}/config", "anonyme.json")  # noqa:
    print("fichiers prêt")


@main.group()
def consultant():
    pass


@consultant.command()
@click.argument("consultant")
def export(consultant):
    consultants_path = f"{DESTINATION_PATH}/consultants/"
    cvs = get_cvs(consultant, consultants_path)
    write_exports(cvs, OUTPUT_PATH, consultant)

@consultant.command()
def list():
    print("ok list")


@consultant.command()
@click.argument("consultant")
def new(consultant):
    print(f"new {consultant}")


@consultant.command()
@click.argument("consultant")
def check(consultant):
    print(f"check {consultant}")


if __name__ == "__main__":
    main()



from weasyprint import HTML, CSS
import json
from .extract_consultants import DossierCompetence
from jinja2 import Template
import markdown


def get_content(source: str) -> str:
    """read le fichier selon la source"""
    with open(source, "r") as content:
        content_str = content.read()
    return content_str


class CV:
    """class pour manipuler un contenu du cv

    :example :
    >>> cv = CV("name='Bob Pipo'
                 poste='Data Scientist'
                sections=[
                    Section(titre='Compétences1', file='### A '),
                    Section(titre='Diplôme1', file='### Diplômes')
                ]")

    """

    def __init__(
        self,
        dossier_competence: DossierCompetence,
        template_path="src/templates/temp_cv.html",
        fileAnomyme="src/config/anonyme.json",
        logo_tete="src/assets/Datalyo_logo_rvb.png",
        logo_pied="src/assets/logo_pied.png",
    ) -> None:
        """initialise le contenu du cv"""
        html_template = template_path
        html_content = get_content(html_template)
        self.dossier_competence = dossier_competence
        self.template = Template(html_content)
        self.fileAnomyme = fileAnomyme
        self.logo_tete_html = "../../../" + logo_tete
        self.logo_pied_html = "../../../" + logo_pied
        self.logo_tete_pdf = logo_tete
        self.logo_pied_pdf = logo_pied

    def to_html_content(self, css_lien, for_pdf: bool):
        """transformer le format md en html"""
        if for_pdf:
            logo_tete = self.logo_tete_pdf
            logo_pied = self.logo_pied_pdf
        else:
            logo_tete = self.logo_tete_html
            logo_pied = self.logo_pied_html
        css_lien = "../../../" + css_lien
        for section in self.dossier_competence.sections:
            section.file = markdown.markdown(section.file)
        html = self.template.render(
            name=self.dossier_competence.name,
            poste=self.dossier_competence.poste,
            sections=self.dossier_competence.sections,
            LIEN_CSS=css_lien,
            LOGO_TETE=logo_tete,
            LOGO_PIED=logo_pied,
        )
        return html

    def anonimize(self, cv: str) -> str:
        """anonimiser le contenu du cv"""
        with open(self.fileAnomyme, "r") as anonimizeFile:
            dictAnonimizd = json.loads(anonimizeFile.read())
        for key in dictAnonimizd:
            cv = cv.replace(key, dictAnonimizd[key])
        return cv

    def to_html_file(self, output_html_file, css_lien, anonimize: bool):
        """transformer le format md en html et sorti la fichier.html"""
        html_content = self.to_html_content(css_lien, for_pdf=False)
        if anonimize:
            html_content = self.anonimize(html_content)
        output_html_file = output_html_file + ".html"
        with open(output_html_file, "w", encoding="utf-8") as html_file:
            html_file.write(html_content)

    def to_pdf_file(self, output_pdf_file, css_lien, anonimize: bool):
        """transformer le format html en pdf et sorti la fichier.pdf"""
        html_content = self.to_html_content(css_lien, for_pdf=True)
        if anonimize:
            html_content = self.anonimize(html_content)
        html = HTML(string=html_content, base_url="")
        output_pdf_file = output_pdf_file + ".pdf"
        with open(css_lien, "rb") as f:
            css = f.read()
        html.write_pdf(
            output_pdf_file,
            stylesheets=[CSS(string=css)],
            presentational_hints=True,
        )



from .cv import CV
from pathlib import Path


def creer_dossier(nom_dossier: str):
    folder_path = Path(nom_dossier)
    folder_path.mkdir(parents=True, exist_ok=True)


class TrigrammerError(Exception):
    pass


def trigrammer(nom_prenom: str):
    """Trigrammer le nom et prenom et creer une dossier named trigramme

    :example :
    >>> print(trigrammer("yao.xin"))
    xya
    """
    try:
        nom = nom_prenom.split(".")[0]
        prenom = nom_prenom.split(".")[1]
        t_nom = nom[0] + nom[1]
        t_prenom = prenom[0]
    except IndexError:
        raise TrigrammerError("wrong format, need to use firstname.name")
    trigramme = t_prenom + t_nom
    return trigramme


def get_output_name(consultant: str, nom_metier: str, anonimized: bool):
    trigramme = trigrammer(consultant)
    if anonimized is True:
        output_name = trigramme + "/" + nom_metier + "_a"
    else:
        output_name = trigramme + "/" + nom_metier
    return output_name


def write_exports(dossiercompetences, output_path, consultant):
    trigramme = trigrammer(consultant)
    creer_dossier(f"{output_path}/{trigramme}")
    for dc in dossiercompetences:
        metier = dc.poste
        cv = CV(
            dossier_competence=dc,
            template_path="src/templates/temp_cv.html",
            fileAnomyme="src/config/anonyme.json",
            logo_tete="src/assets/Datalyo_logo_rvb.png",
            logo_pied="src/assets/logo_pied.png",
        )
        output_name = get_output_name(consultant, metier, anonimized=False)
        output_name_anonimized = get_output_name(
            consultant, metier, anonimized=True
        )  # noqa:
        output_p = f"{output_path}/{output_name}"
        output_p_a = f"{output_path}/{output_name_anonimized}"
        cv.to_html_file(
            output_p,
            "src/assets/test.css",
            anonimize=False,
        )
        cv.to_pdf_file(
            output_p,
            "src/assets/test.css",
            anonimize=False,
        )
        cv.to_html_file(
            output_p_a,
            "src/assets/test.css",
            anonimize=True,
        )
        cv.to_pdf_file(
            output_p_a,
            "src/assets/test.css",
            anonimize=True,
        )



from pydantic import BaseModel
from typing import List
import yaml


class Section(BaseModel):
    titre: str = "Mon titre"
    file: str = "fichier.md"


class Poste(BaseModel):
    poste: str
    structure: str = "standard"
    sections: List[Section]


"""
    @validator('structure')
    def sections(self, sections, standard):
        if sections == []:
            if structure=="standard":
                return [
                    Section("Valeur ajoutée sur votre mission","valeur.md"),
                    Section("Compétences clés","competence.md"),
                    Section("Diplômes et certifications","diplome.md"),
                    Section("Langues parlées","langague.md"),
                    Section("Formations suivies","formation.md"),
                    Section("Expériences significatives","experience_s.md"),
                    Section("Expériences de formateur","experience_f.md")
                ]
            if structure == "formation":
                return [
                    Section("Compétences clés","competence.md"),
                    Section("Valeur ajoutée sur votre mission","valeur.md")
                ]
"""


class ExportConfig(BaseModel):
    nom_prenom: str
    dossiers: List[Poste]


class DossierCompetencePret(BaseModel):
    name: str
    poste: str
    sections: list[Section]
    # ex:[Section(titre='Compétences', file='valeur_ajoute.md'), Section(titre='Expériences', file='diplome.md')] # noqa:


class DossierCompetence(BaseModel):
    name: str
    poste: str
    sections: list[Section]
    # ex:section=[Section(titre='Compétences', file='# valeur_ajoute'), Section(titre='Expériences', file='#diplome')] # noqa:


"""
class StandardPoste(Poste):
    nom_poste: str
    sections = [
        Section("Valeur ajoutée sur votre mission","valeur.md"),
        Section("Compétences clés","competence.md"),
        Section("Diplômes et certifications","diplome.md"),
        Section("Langues parlées","langague.md"),
        Section("Formations suivies","formation.md"),
        Section("Expériences significatives","experience_s.md"),
        Section("Expériences de formateur","experience_f.md")
    ]
class FormateurPoste(Poste):
    nom_poste: str
    sections = [
        Section("Valeur ajoutée sur votre mission","valeur.md"),
        Section("Compétences clés","competence.md"),
        Section("Diplômes et certifications","diplome.md"),
        Section("Langues parlées","langague.md"),
        Section("Formations suivies","formation.md"),
        Section("Expériences de formateur","experience_f.md"),
        Section("Expériences significatives","experience_s.md")
    ]
class CustomPoste(Poste):
    nom_poste: str
    sections: List[Section]
"""


def get_source_content(source: str) -> str:
    """read le fichier selon la source"""
    with open(source, "r") as content:
        content_str = content.read()
    return content_str


def read_yaml(file_path: str) -> ExportConfig:
    """Lire le le fichier yaml"""
    with open(file_path, "r") as stream:
        config = yaml.safe_load(stream)
    return ExportConfig(**config)


def flat_export(config: ExportConfig) -> list:
    """exporter en list[DC]"""
    name = config.nom_prenom
    dc_liste = []
    for dossier in config.dossiers:
        dc_liste.append(
            DossierCompetencePret(
                name=name, poste=dossier.poste, sections=dossier.sections
            )
        )
    return dc_liste


def extract_contenue(
    consultant_path: str, dcp: DossierCompetencePret
) -> DossierCompetence:
    """extract le contenue md"""
    name = dcp.name
    poste = dcp.poste
    liste_Section = []
    for section in dcp.sections:
        md = get_source_content(consultant_path + "/" + section.file)
        liste_Section.append(Section(titre=section.titre, file=md))
    return DossierCompetence(name=name, poste=poste, sections=liste_Section)


def get_dc_contenue(
    consultant_path: str, liste_dcp: list[DossierCompetencePret]
) -> list[DossierCompetence]:
    liste_dc = []
    for dcp in liste_dcp:
        liste_dc.append(extract_contenue(consultant_path, dcp))
    return liste_dc


def get_cvs(consultant: str, consultants_path: str) -> list:
    consultant_path = f"{consultants_path}/{consultant}"
    config = read_yaml(f"{consultant_path}/export.yaml")
    liste_dcp = flat_export(config)
    dc_liste = get_dc_contenue(consultant_path, liste_dcp)
    return dc_liste



import shutil
from pathlib import Path


def creer_dossier(nom_dossier: str):
    folder_path = Path(nom_dossier)
    folder_path.mkdir(parents=True, exist_ok=True)


def copy_file(source_dossier, cible_dossier, file_name):
    path = Path(__file__).parent
    path_copier = path.parent / source_dossier / file_name
    path_coller = cible_dossier + "/" + file_name
    shutil.copyfile(path_copier, path_coller)



import pytest
from data_skill_hub.export import (
    trigrammer,
    TrigrammerError,
    get_output_name,
)


# part test


def test_trigrammer():
    print("____test_trigrammer____")
    assert trigrammer("yao.xin") == "xya"
    assert trigrammer("yyy.xin") == "xyy"
    assert trigrammer("y_dsqghjao.xin") == "xy_"
    assert trigrammer("yqsdg_dsqghjao.xin") == "xyq"
    assert trigrammer("yao.jin.xin") == "jya"  # Identifiez le premier point


def test_trigrammer_failed():
    with pytest.raises(TrigrammerError):
        trigrammer("yao..xin")


def test_get_output_name():
    print("____test_get_output_name____")
    assert (
        get_output_name("yao.xin", "dataScience", anonimized=True)
        == "xya/dataScience_a"
    )
    assert (
        get_output_name("yao/abc.xin", "dataScience", anonimized=True)  # noqa:
        == "xya/dataScience_a"
    )
    assert (
        get_output_name("y/a/o/ab.x", "dataScience", anonimized=True)  # noqa:
        == "xy//dataScience_a"
    )
    assert (
        get_output_name("yao.xin", "dataScience", anonimized=False) == "xya/dataScience"
    )
    assert (
        get_output_name("yao/abc.xin", "dataScience", anonimized=False)  # noqa:
        == "xya/dataScience"
    )
    assert (
        get_output_name("y/a/o/ab.x", "dataScience", anonimized=False)  # noqa:
        == "xy//dataScience"
    )



#!/usr/bin/env python

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup

setup(
    name="dataskillhub",
    version="1.0.17",
    description="Anonymisation et filtrage des termes dans le CV, décoration et style des CV produits.",  # noqa:
    author="Xin Yao",
    author_email="xin.yao@datalyo.com",
    url="https://gitlab-datalyo.francecentral.cloudapp.azure.com/dossier-de-comp-tences/dossiercompetence",  # noqa:
    packages=find_packages(),
    include_package_data=True,
    install_requires=["click","pydantic","PyYAML","Markdown","weasyprint","Jinja2","flake8","black","pytest"],  # noqa:
    entry_points={
        "console_scripts": [
            "dsh_init = data_skill_hub.main:init",
            "dsh_consultant_export = data_skill_hub.main:export"
        ]
    },
)
